@@ -19,7 +19,7 @@
 #               4) http://www.fileformat.info/format/psd/egff.htm
 #               5) http://www.telegraphics.com.au/svn/psdparse/trunk/resources.c
 #               6) http://libpsd.graphest.com/files/Photoshop%20File%20Formats.pdf
-#               7) http://www.adobe.com/devnet-apps/photoshop/fileformatashtml/PhotoshopFileFormats.htm
+#               7) http://www.adobe.com/devnet-apps/photoshop/fileformatashtml/
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Photoshop;
@@ -28,7 +28,7 @@ use strict;
 use vars qw($VERSION $AUTOLOAD $iptcDigestInfo);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.44';
+$VERSION = '1.46';
 
 sub ProcessPhotoshop($$$);
 sub WritePhotoshop($$$);
@@ -50,6 +50,22 @@ my %psdMap = (
     MakerNotes   => 'ExifIFD',
 );
 
+# tag information for PhotoshopThumbnail and PhotoshopBGRThumbnail
+my %thumbnailInfo = (
+    Writable => 'undef',
+    Protected => 1,
+    RawConv => 'my $img=substr($val,0x1c); $self->ValidateImage(\$img,$tag)',
+    ValueConvInv => q{
+        my $et = new Image::ExifTool;
+        my @tags = qw{ImageWidth ImageHeight FileType};
+        my $info = $et->ImageInfo(\$val, @tags);
+        my ($w, $h, $type) = @$info{@tags};
+        $w and $h and $type eq 'JPEG' or warn("Not a valid JPEG image\n"), return undef;
+        my $wbytes = int(($w * 24 + 31) / 32) * 4;
+        return pack('N6n2', 1, $w, $h, $wbytes, $wbytes * $h, length($val), 24, 1) . $val;
+    },
+);
+
 # Photoshop APP13 tag table
 # (set Unknown flag for information we don't want to display normally)
 %Image::ExifTool::Photoshop::Main = (
@@ -109,7 +125,7 @@ my %psdMap = (
     0x0409 => {
         Name => 'PhotoshopBGRThumbnail',
         Notes => 'this is a JPEG image, but in BGR format instead of RGB',
-        RawConv => 'my $img=substr($val,0x1c);$self->ValidateImage(\$img,$tag)',
+        %thumbnailInfo,
     },
     0x040a => {
         Name => 'CopyrightFlag',
@@ -129,7 +145,7 @@ my %psdMap = (
     },
     0x040c => {
         Name => 'PhotoshopThumbnail',
-        RawConv => 'my $img=substr($val,0x1c);$self->ValidateImage(\$img,$tag)',
+        %thumbnailInfo,
     },
     0x040d => {
         Name => 'GlobalAngle',
@@ -238,6 +254,7 @@ my %psdMap = (
     0x043d => { Unknown => 1, Name => 'WindowsDEVMODE' }, #7
     0x043e => { Unknown => 1, Name => 'AutoSaveFilePath' }, #7
     0x043f => { Unknown => 1, Name => 'AutoSaveFormat' }, #7
+    0x0440 => { Unknown => 1, Name => 'PathSelectionState' }, #7
     # 0x07d0-0x0bb6 Path information
     0x0bb7 => {
         Name => 'ClippingPathName',
@@ -248,8 +265,10 @@ my %psdMap = (
             return Image::ExifTool::Photoshop::ConvertPascalString($self,$val);
         },
     },
+    0x0bb8 => { Unknown => 1, Name => 'OriginPathInfo' }, #7
     # 0x0fa0-0x1387 - plug-in resources (ref 7)
     0x1b58 => { Unknown => 1, Name => 'ImageReadyVariables' }, #7
+    0x1b59 => { Unknown => 1, Name => 'ImageReadyDataSets' }, #7
     0x1f40 => { Unknown => 1, Name => 'LightroomWorkflow' }, #7
     0x2710 => { Unknown => 1, Name => 'PrintFlagsInfo' },
 );
@@ -599,7 +618,7 @@ be preserved when copying Photoshop information via user-defined tags.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -616,7 +635,7 @@ under the same terms as Perl itself.
 
 =item L<http://libpsd.graphest.com/files/Photoshop%20File%20Formats.pdf>
 
-=item L<http://www.adobe.com/devnet-apps/photoshop/fileformatashtml/PhotoshopFileFormats.htm>
+=item L<http://www.adobe.com/devnet-apps/photoshop/fileformatashtml/>
 
 =back
 
