@@ -164,52 +164,57 @@ my %formatMinMax = (
             0x200131e => 'PL210, PL211 / VLUU PL210, PL211',
             0x2701317 => 'PL20,PL21 / VLUU PL20,PL21',
             0x2a0001b => 'WP10 / VLUU WP10 / AQ100',
-            0x3000000 => 'DV150F / DV151F / DV155F',
-            0x3000000 => 'NX mini',
-            0x3000000 => 'NX3000',
-            0x3000000 => 'ST150F / ST151F / ST152F',
-            0x3000000 => 'WB250F / WB251F / WB252F',
-            0x3000000 => 'WB30F / WB31F / WB32F',
-            0x3000000 => 'WB350F / WB351F / WB352F',
-            0x3000000 => 'WB800F',
-            0x3a00018 => 'ES30 / VLUU ES30',
-            0x3a00018 => 'ES80 / ES81',
-            0x3a00018 => 'PL200 / VLUU PL200',
-            0x3a00018 => 'PL80 / VLUU PL80 / SL630 / PL81',
-            0x3a00018 => 'PL90 / VLUU PL90',
-            0x3a00018 => 'WB1100F / WB1101F / WB1102F',
-            0x3a00018 => 'WB2200F',
+            0x3000000 => 'Various Models (0x3000000)',
+           #0x3000000 => 'DV150F / DV151F / DV155F',
+           #0x3000000 => 'NX mini',
+           #0x3000000 => 'NX3000',
+           #0x3000000 => 'ST150F / ST151F / ST152F',
+           #0x3000000 => 'WB250F / WB251F / WB252F',
+           #0x3000000 => 'WB30F / WB31F / WB32F',
+           #0x3000000 => 'WB350F / WB351F / WB352F',
+           #0x3000000 => 'WB800F',
+            0x3a00018 => 'Various Models (0x3a00018)',
+           #0x3a00018 => 'ES30 / VLUU ES30',
+           #0x3a00018 => 'ES80 / ES81',
+           #0x3a00018 => 'PL200 / VLUU PL200',
+           #0x3a00018 => 'PL80 / VLUU PL80 / SL630 / PL81',
+           #0x3a00018 => 'PL90 / VLUU PL90',
+           #0x3a00018 => 'WB1100F / WB1101F / WB1102F',
+           #0x3a00018 => 'WB2200F',
             0x400101f => 'ST1000 / ST1100 / VLUU ST1000 / CL65',
             0x4001022 => 'ST550 / VLUU ST550 / TL225',
-            0x4001025 => 'DV300 / DV300F / DV305F',
-            0x4001025 => 'ST500 / VLUU ST500 / TL220',
-            0x4001025 => 'ST200 / ST200F / ST201 / ST201F / ST205F',
+            0x4001025 => 'Various Models (0x4001025)',
+           #0x4001025 => 'DV300 / DV300F / DV305F',
+           #0x4001025 => 'ST500 / VLUU ST500 / TL220',
+           #0x4001025 => 'ST200 / ST200F / ST201 / ST201F / ST205F',
             0x400103e => 'VLUU ST5500, ST5500, CL80',
             0x4001041 => 'VLUU ST5000, ST5000, TL240',
             0x4001043 => 'ST70 / VLUU ST70 / ST71',
-            0x400130a => 'VLUU ST100, ST100',
-            0x400130a => 'VLUU ST600, ST600',
-            0x400130a => 'VLUU ST80, ST80',
+            0x400130a => 'Various Models (0x400130a)',
+           #0x400130a => 'VLUU ST100, ST100',
+           #0x400130a => 'VLUU ST600, ST600',
+           #0x400130a => 'VLUU ST80, ST80',
             0x400130e => 'ST90,ST91 / VLUU ST90,ST91',
             0x4001313 => 'VLUU ST95, ST95',
             0x4a00015 => 'VLUU ST60',
-            0x4a0135b => 'ST30',
-            0x4a0135b => 'ST65 / VLUU ST65 / ST67',
-            0x5000000 => 'EX2F',
-            0x5000000 => 'NX1000',
-            0x5000000 => 'NX20',
-            0x5000000 => 'NX200',
-            0x5000000 => 'NX210',
-            0x5000000 => 'ST96',
-            0x5000000 => 'WB750',
-            0x5000000 => 'ST700',
-            0x5001038 => 'EK-GN120',
-            0x5001038 => 'HMX-E10',
-            0x5001038 => 'NX1',
-            0x5001038 => 'NX2000',
-            0x5001038 => 'NX30',
-            0x5001038 => 'NX300',
-            0x5001038 => 'WB2000',
+            0x4a0135b => 'ST30, ST65 / VLUU ST65 / ST67',
+            0x5000000 => 'Various Models (0x5000000)',
+           #0x5000000 => 'EX2F',
+           #0x5000000 => 'NX1000',
+           #0x5000000 => 'NX20',
+           #0x5000000 => 'NX200',
+           #0x5000000 => 'NX210',
+           #0x5000000 => 'ST96',
+           #0x5000000 => 'WB750',
+           #0x5000000 => 'ST700',
+            0x5001038 => 'Various Models (0x5001038)',
+           #0x5001038 => 'EK-GN120',
+           #0x5001038 => 'HMX-E10',
+           #0x5001038 => 'NX1',
+           #0x5001038 => 'NX2000',
+           #0x5001038 => 'NX30',
+           #0x5001038 => 'NX300',
+           #0x5001038 => 'WB2000',
             0x500103a => 'WB650 / VLUU WB650 / WB660',
             0x500103c => 'WB600 / VLUU WB600 / WB610',
             0x500133e => 'WB150 / WB150F / WB152 / WB152F / WB151',
