@@ -18,9 +18,9 @@ use strict;
 use vars qw($VERSION %sigmaLensTypes);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.15';
+$VERSION = '1.16';
 
-# sigma LensType lookup (ref PH)
+# sigma LensType lookup (ref 3)
 %sigmaLensTypes = (
     Notes => q{
         Decimal values have been added to differentiate lenses which would otherwise
@@ -29,77 +29,119 @@ $VERSION = '1.15';
     },
     # 0 => 'Sigma 50mm F2.8 EX Macro', (0 used for other lenses too)
     # 8 - 18-125mm LENSARANGE@18mm=22-4
-    16 => 'Sigma 18-50mm F3.5-5.6 DC',
-    106 => 'Sigma 150mm F2.8 EX DG OS HSM APO Macro', #3
-    107 => 'Sigma APO Macro 180mm F2.8 EX DG OS HSM', #3
-    129 => 'Sigma 14mm F2.8 EX Aspherical',
-    131 => 'Sigma 17-70mm F2.8-4.5 DC Macro',
-    145 => 'Sigma Lens (145)',
-    145.1 => 'Sigma 15-30mm F3.5-4.5 EX DG Aspherical',
-    145.2 => 'Sigma 18-50mm F2.8 EX DG', #(NC)
-    145.3 => 'Sigma 20-40mm F2.8 EX DG',
-    152 => 'Sigma APO 800mm F5.6 EX DG HSM', #3
+    16 => 'Sigma 18-50mm F3.5-5.6 DC', #PH
+    103 => 'Sigma 180mm F3.5 EX IF HSM APO Macro',
+    104 => 'Sigma 150mm F2.8 EX DG HSM APO Macro',
+    105 => 'Sigma 180mm F3.5 EX DG HSM APO Macro',
+    106 => 'Sigma 150mm F2.8 EX DG OS HSM APO Macro',
+    107 => 'Sigma 180mm F2.8 EX DG OS HSM APO Macro',
+    129 => 'Sigma 14mm F2.8 EX Aspherical', #PH
+    131 => 'Sigma 17-70mm F2.8-4.5 DC Macro', #PH
+    134 => 'Sigma 100-300mm F4 EX DG HSM APO',
+    135 => 'Sigma 120-300mm F2.8 EX DG HSM APO',
+    136 => 'Sigma 120-300mm F2.8 EX DG OS HSM APO',
+    137 => 'Sigma 120-300mm F2.8 DG OS HSM | S',
+    143 => 'Sigma 600mm F8 Mirror',
+    145 => 'Sigma Lens (145)', #PH
+    145.1 => 'Sigma 15-30mm F3.5-4.5 EX DG Aspherical', #PH
+    145.2 => 'Sigma 18-50mm F2.8 EX DG', #PH (NC)
+    145.3 => 'Sigma 20-40mm F2.8 EX DG', #PH
+    152 => 'Sigma APO 800mm F5.6 EX DG HSM',
     165 => 'Sigma 70-200mm F2.8 EX', # ...but what specific model?:
     # 70-200mm F2.8 EX APO - Original version, minimum focus distance 1.8m (1999)
     # 70-200mm F2.8 EX DG - Adds 'digitally optimized' lens coatings to reduce flare (2005)
     # 70-200mm F2.8 EX DG Macro (HSM) - Minimum focus distance reduced to 1m (2006)
     # 70-200mm F2.8 EX DG Macro HSM II - Improved optical performance (2007)
-    169 => 'Sigma 18-50mm F2.8 EX DC', #(NC)
-    184 => 'Sigma 500mm F4.5 EX DG APO HSM', #3
-    195 => 'Sigma 300mm F2.8 EX APO DG HSM', #3
-    201 => 'Sigma 10-20mm F4-5.6 EX DC HSM', #3
-    202 => 'Sigma 10-20mm F3.5 EX DC HSM', #3
-    203 => 'Sigma 8-16mm F4.5-5.6 DC HSM', #3
-    204 => 'Sigma 12-24mm F4.5-5.6 DG HSM II', #3
-    258 => 'Sigma 105mm F2.8 EX DG OS HSM Macro', #3
+    169 => 'Sigma 18-50mm F2.8 EX DC', #PH (NC)
+    183 => 'Sigma 500mm F4.5 EX HSM APO',
+    184 => 'Sigma 500mm F4.5 EX DG HSM APO',
+    194 => 'Sigma 300mm F2.8 EX HSM APO',
+    195 => 'Sigma 300mm F2.8 EX DG HSM APO',
+    200 => 'Sigma 12-24mm F4.5-5.6 EX DG ASP HSM',
+    201 => 'Sigma 10-20mm F4-5.6 EX DC HSM',
+    202 => 'Sigma 10-20mm F3.5 EX DC HSM',
+    203 => 'Sigma 8-16mm F4.5-5.6 DC HSM',
+    204 => 'Sigma 12-24mm F4.5-5.6 DG HSM II',
+    210 => 'Sigma 18-35mm F1.8 DC HSM | A',
+    256 => 'Sigma 105mm F2.8 EX Macro',
+    257 => 'Sigma 105mm F2.8 EX DG Macro',
+    258 => 'Sigma 105mm F2.8 EX DG OS HSM Macro',
     270 => 'Sigma 70mm F2.8 EX DG Macro', #2 (SD1)
-    300 => 'Sigma 30mm F1.4 EX DC HSM', #3
-    310 => 'Sigma 50mm F1.4 EX DG HSM', #3
-    320 => 'Sigma 85mm F1.4 EX DG HSM', #3
-    330 => 'Sigma 30mm F2.8 EX DN', #3
-    340 => 'Sigma 35mm F1.4 DG HSM', #3
-    346 => 'Sigma 50mm F2.8 EX DG Macro', #3
-    400 => 'Sigma 9mm F2.8 EX DN', #3
-    411 => 'Sigma 20mm F1.8 EX DG ASP RF', #3
-    432 => 'Sigma 24mm F1.8 EX DG ASP Macro', #3
-    440 => 'Sigma 28mm F1.8 EX DG ASP Macro', #3
-    476 => 'Sigma 15mm F2.8 EX DG Diagonal Fisheye', #3
-    477 => 'Sigma 10mm F2.8 EX DC HSM Fisheye', #3
-    485 => 'Sigma 8mm F3.5 EX DG Circular Fisheye', #3
-    486 => 'Sigma 4.5mm F2.8 EX DC HSM Circular Fisheye', #3
-    508 => 'Sigma 70-300mm F4-5.6 APO DG Macro', #3
-    509 => 'Sigma 70-300mm F4-5.6 DG Macro', #3
-    571 => 'Sigma 24-70mm F2.8 IF EX DG HSM', #3
-    572 => 'Sigma 70-300mm F4-5.6 DG OS', #3
-    581 => 'Sigma 18-50mm F2.8 EX DC Macro', # (SD1)
-    583 => 'Sigma 17-50mm F2.8 EX DC OS HSM', # (also SD1 Kit, is this HSM? - PH)
-    589 => 'Sigma APO 70-200mm F2.8 EX DG OS HSM', #3
-    595 => 'Sigma 300-800mm F5.6 EX DG APO HSM', #3
-    597 => 'Sigma 200-500mm F2.8 APO EX DG', #3
-   '5A8'=> 'Sigma 70-300mm F4-5.6 APO DG Macro (Motorized)', #3
-   '5A9'=> 'Sigma 70-300mm F4-5.6 DG Macro (Motorized)', #3
-    668 => 'Sigma 17-70mm F2.8-4 DC Macro OS HSM', #3
-    686 => 'Sigma 50-200mm F4-5.6 DC OS HSM', #3
-    691 => 'Sigma 50-150mm F2.8 EX DC APO HSM II', #3
-    692 => 'Sigma APO 50-150mm F2.8 EX DC OS HSM', #3
-    728 => 'Sigma 120-400mm F4.5-5.6 DG APO OS HSM', #3
-    737 => 'Sigma 150-500mm F5-6.3 APO DG OS HSM', #3
-    738 => 'Sigma 50-500mm F4.5-6.3 APO DG OS HSM', #3
-    824 => 'Sigma 1.4X Teleconverter EX APO DG', #3
-    853 => 'Sigma 18-125mm F3.8-5.6 DC OS HSM', #3
+    300 => 'Sigma 30mm F1.4 EX DC HSM',
+    301 => 'Sigma 30mm F1.4 DC HSM | A',
+    310 => 'Sigma 50mm F1.4 EX DG HSM',
+    311 => 'Sigma 50mm F1.4 DG HSM | A',
+    320 => 'Sigma 85mm F1.4 EX DG HSM',
+    330 => 'Sigma 30mm F2.8 EX DN',
+    340 => 'Sigma 35mm F1.4 DG HSM',
+    345 => 'Sigma 50mm F2.8 EX Macro',
+    346 => 'Sigma 50mm F2.8 EX DG Macro',
+    400 => 'Sigma 9mm F2.8 EX DN',
+    401 => 'Sigma 24mm F1.4 DG HSM | A',
+    411 => 'Sigma 20mm F1.8 EX DG ASP RF',
+    432 => 'Sigma 24mm F1.8 EX DG ASP Macro',
+    440 => 'Sigma 28mm F1.8 EX DG ASP Macro',
+    461 => 'Sigma 14mm F2.8 EX ASP HSM',
+    475 => 'Sigma 15mm F2.8 EX Diagonal FishEye',
+    476 => 'Sigma 15mm F2.8 EX DG Diagonal Fisheye',
+    477 => 'Sigma 10mm F2.8 EX DC HSM Fisheye',
+    483 => 'Sigma 8mm F4 EX Circular Fisheye',
+    484 => 'Sigma 8mm F4 EX DG Circular Fisheye',
+    485 => 'Sigma 8mm F3.5 EX DG Circular Fisheye',
+    486 => 'Sigma 4.5mm F2.8 EX DC HSM Circular Fisheye',
+    506 => 'Sigma 70-300mm F4-5.6 APO Macro Super II',
+    507 => 'Sigma 70-300mm F4-5.6 DL Macro Super II',
+    508 => 'Sigma 70-300mm F4-5.6 DG APO Macro',
+    509 => 'Sigma 70-300mm F4-5.6 DG Macro',
+    510 => 'Sigma 17-35 F2.8-4 EX DG ASP',
+    512 => 'Sigma 15-30mm F3.5-4.5 EX DG ASP DF',
+    513 => 'Sigma 20-40mm F2.8 EX DG',
+    519 => 'Sigma 17-35 F2.8-4 EX ASP HSM',
+    520 => 'Sigma 100-300mm F4.5-6.7 DL',
+    521 => 'Sigma 18-50mm F3.5-5.6 DC Macro',
+    527 => 'Sigma 100-300mm F4 EX IF HSM',
+    529 => 'Sigma 120-300mm F2.8 EX HSM IF APO',
+    547 => 'Sigma 24-60mm F2.8 EX DG',
+    548 => 'Sigma 24-70mm F2.8 EX DG Macro',
+    549 => 'Sigma 28-70mm F2.8 EX DG',
+    566 => 'Sigma 70-200mm F2.8 EX IF APO',
+    567 => 'Sigma 70-200mm F2.8 EX IF HSM APO',
+    568 => 'Sigma 70-200mm F2.8 EX DG IF HSM APO',
+    569 => 'Sigma 70-200 F2.8 EX DG HSM APO Macro',
+    571 => 'Sigma 24-70mm F2.8 IF EX DG HSM',
+    572 => 'Sigma 70-300mm F4-5.6 DG OS',
+    579 => 'Sigma 70-200mm F2.8 EX DG HSM APO Macro', # (also II version)
+    580 => 'Sigma 18-50mm F2.8 EX DC',
+    581 => 'Sigma 18-50mm F2.8 EX DC Macro', #PH (SD1)
+    582 => 'Sigma 18-50mm F2.8 EX DC HSM Macro',
+    583 => 'Sigma 17-50mm F2.8 EX DC OS HSM', #PH (also SD1 Kit, is this HSM? - PH)
+    589 => 'Sigma APO 70-200mm F2.8 EX DG OS HSM',
+    595 => 'Sigma 300-800mm F5.6 EX DG APO HSM',
+    597 => 'Sigma 200-500mm F2.8 APO EX DG',
+   '5A8'=> 'Sigma 70-300mm F4-5.6 APO DG Macro (Motorized)',
+   '5A9'=> 'Sigma 70-300mm F4-5.6 DG Macro (Motorized)',
+    668 => 'Sigma 17-70mm F2.8-4 DC Macro OS HSM',
+    686 => 'Sigma 50-200mm F4-5.6 DC OS HSM',
+    691 => 'Sigma 50-150mm F2.8 EX DC APO HSM II',
+    692 => 'Sigma APO 50-150mm F2.8 EX DC OS HSM',
+    728 => 'Sigma 120-400mm F4.5-5.6 DG APO OS HSM',
+    737 => 'Sigma 150-500mm F5-6.3 APO DG OS HSM',
+    738 => 'Sigma 50-500mm F4.5-6.3 APO DG OS HSM',
+    824 => 'Sigma 1.4X Teleconverter EX APO DG',
+    853 => 'Sigma 18-125mm F3.8-5.6 DC OS HSM',
     861 => 'Sigma 18-50mm F2.8-4.5 DC OS HSM', #2 (SD1)
-    876 => 'Sigma 2.0X Teleconverter EX APO DG', #3
-    880 => 'Sigma 18-250mm F3.5-6.3 DC OS HSM', #3
-    882 => 'Sigma 18-200mm F3.5-6.3 II DC OS HSM', #3
-    883 => 'Sigma 18-250mm F3.5-6.3 DC Macro OS HSM', #3
-    1003 => 'Sigma 19mm F2.8', # (DP1 Merrill kit)
-    1004 => 'Sigma 30mm F2.8', # (DP2 Merrill kit)
-    1005 => 'Sigma 50mm F2.8 Macro', # (DP3 Merrill kit)
+    876 => 'Sigma 2.0X Teleconverter EX APO DG',
+    880 => 'Sigma 18-250mm F3.5-6.3 DC OS HSM',
+    882 => 'Sigma 18-200mm F3.5-6.3 II DC OS HSM',
+    883 => 'Sigma 18-250mm F3.5-6.3 DC Macro OS HSM',
+    1003 => 'Sigma 19mm F2.8', #PH (DP1 Merrill kit)
+    1004 => 'Sigma 30mm F2.8', #PH (DP2 Merrill kit)
+    1005 => 'Sigma 50mm F2.8 Macro', #PH (DP3 Merrill kit)
     1006 => 'Sigma 19mm F2.8', #2 (DP1 Quattro kit)
-    1007 => 'Sigma 30mm F2.8', # (DP2 Quattro kit)
-    8900 => 'Sigma 70-300mm F4-5.6 DG OS', # (SD15)
-   'A100'=> 'Sigma 24-70mm F2.8 DG Macro', # (SD15)
-    # 'FFFF' - seen this for a 28-70mm F2.8 lens
+    1007 => 'Sigma 30mm F2.8', #PH (DP2 Quattro kit)
+    8900 => 'Sigma 70-300mm F4-5.6 DG OS', #PH (SD15)
+   'A100'=> 'Sigma 24-70mm F2.8 DG Macro', #PH (SD15)
+    # 'FFFF' - seen this for a 28-70mm F2.8 lens - PH
 );
 
 %Image::ExifTool::Sigma::Main = (
